"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.frontmatter = void 0;
const helpers_1 = require("../support/helpers");
const utils_1 = require("../support/utils");
function frontmatter(context, page) {
    const globals = context.getOption('frontmatterGlobals');
    const yaml = `---\n${Object.entries({
        ...getBaseFrontmatterVars(page, context),
        ...(page.model.comment && getFrontmatterTags(page.model.comment, context)),
        ...(globals && getGlobals(globals)),
    })
        .map(([key, value]) => `${key}: ${typeof value === 'string' ? `"${value}"` : value}`)
        .join('\n')}\n---`;
    return yaml;
}
exports.frontmatter = frontmatter;
function getBaseFrontmatterVars(page, context) {
    return {
        [toVariable('title', context.getOption('frontmatterNamingConvention'))]: (0, utils_1.unEscapeChars)(context.partials.pageTitle(page)),
    };
}
function getGlobals(globals) {
    if (typeof globals === 'string') {
        return JSON.parse(globals);
    }
    return globals;
}
function getFrontmatterTags(comment, context) {
    var _a;
    if (!comment) {
        return {};
    }
    if ((_a = comment.blockTags) === null || _a === void 0 ? void 0 : _a.length) {
        const tags = comment.blockTags
            .filter((tag) => { var _a; return (_a = context.getOption('frontmatterTags')) === null || _a === void 0 ? void 0 : _a.includes((0, helpers_1.getTagName)(tag)); })
            .reduce((prev, current) => {
            const tagName = (0, helpers_1.getTagName)(current);
            const tagValue = current.content
                .filter((commentPart) => commentPart.kind === 'text')
                .map((commentPart) => (0, utils_1.stripLineBreaks)(commentPart.text, false))
                .join('');
            return {
                ...prev,
                [toVariable(tagName, context.getOption('frontmatterNamingConvention'))]: toValue(tagValue),
            };
        }, {});
        return tags;
    }
    return {};
}
function toValue(tagValue) {
    return Number(tagValue) || tagValue;
}
function toVariable(str, namingConvention) {
    if (namingConvention === 'snakeCase') {
        return toSnakeCase(str);
    }
    if (namingConvention === 'kebabCase') {
        return toKebabCase(str);
    }
    if (namingConvention === 'pascalCase') {
        return toPascalCase(str);
    }
    return str;
}
function toSnakeCase(str) {
    var _a;
    return (((_a = str
        .match(/[A-Z]{2,}(?=[A-Z][a-z]+[0-9]*|\b)|[A-Z]?[a-z]+[0-9]*|[A-Z]|[0-9]+/g)) === null || _a === void 0 ? void 0 : _a.map((s) => s.toLowerCase()).join('_')) || '');
}
function toPascalCase(str) {
    return (str.match(/[a-zA-Z0-9]+/g) || [])
        .map((w) => `${w.charAt(0).toUpperCase()}${w.slice(1)}`)
        .join('');
}
function toKebabCase(str) {
    var _a;
    return (((_a = str
        .match(/[A-Z]{2,}(?=[A-Z][a-z]+[0-9]*|\b)|[A-Z]?[a-z]+[0-9]*|[A-Z]|[0-9]+/g)) === null || _a === void 0 ? void 0 : _a.join('-').toLowerCase()) || '');
}
