"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.declarationMember = void 0;
const typedoc_1 = require("typedoc");
const els_1 = require("../support/els");
const helpers_1 = require("../support/helpers");
const utils_1 = require("../support/utils");
function declarationMember(context, declaration, parentHeadingLevel) {
    const md = [];
    if (parentHeadingLevel) {
        md.push(declarationBody(context, declaration, parentHeadingLevel));
    }
    else {
        md.push(declarationBody(context, declaration));
    }
    return md.join('\n\n');
}
exports.declarationMember = declarationMember;
function declarationBody(context, declaration, parentHeadingLevel) {
    var _a, _b, _c;
    const md = [];
    const headingLevel = (parentHeadingLevel
        ? parentHeadingLevel
        : (0, helpers_1.getReflectionHeadingLevel)(declaration, context.getOption('groupByKinds'))) + 1;
    const typeDeclaration = (_a = declaration.type) === null || _a === void 0 ? void 0 : _a.declaration;
    const isTypeLiteralProperty = declaration.kindOf(typedoc_1.ReflectionKind.Property) &&
        ((_b = declaration.parent) === null || _b === void 0 ? void 0 : _b.kindOf(typedoc_1.ReflectionKind.TypeLiteral));
    const titleSuffix = isTypeLiteralProperty
        ? ` - ${(0, utils_1.escapeChars)(declaration.name)}`
        : '';
    if (context.getOption('indentifiersAsCodeBlocks')) {
        md.push((0, els_1.codeBlock)(context.partials.declarationMemberIdentifier(declaration)));
    }
    else {
        md.push(`${!parentHeadingLevel ? '>' : ''} ${context.partials.declarationMemberIdentifier(declaration)}`);
    }
    if (declaration.comment) {
        md.push(context.partials.comment(declaration.comment, headingLevel));
    }
    if (!parentHeadingLevel && declaration.sources) {
        md.push(context.partials.sources(declaration));
    }
    if (declaration.typeParameters) {
        md.push((0, els_1.heading)(headingLevel, `Type parameters${titleSuffix}`));
        md.push(context.partials.typeParametersTable(declaration.typeParameters));
    }
    if (typeDeclaration) {
        if (typeDeclaration === null || typeDeclaration === void 0 ? void 0 : typeDeclaration.indexSignature) {
            md.push((0, els_1.heading)(headingLevel, `Index signature${titleSuffix}`));
            md.push(context.partials.indexSignatureTitle(typeDeclaration.indexSignature));
        }
        md.push((0, els_1.heading)(headingLevel, `Type declaration${titleSuffix}`));
        if (typeDeclaration === null || typeDeclaration === void 0 ? void 0 : typeDeclaration.signatures) {
            typeDeclaration.signatures.forEach((signature) => {
                md.push(context.partials.signatureMember(signature, headingLevel));
            });
        }
        if ((_c = typeDeclaration === null || typeDeclaration === void 0 ? void 0 : typeDeclaration.children) === null || _c === void 0 ? void 0 : _c.length) {
            if (context.getOption('typeDeclarationFormat').toLowerCase() === 'table') {
                md.push(context.partials.propertiesTable(typeDeclaration.children));
            }
            else {
                md.push((0, els_1.blockQuoteBlock)(context.partials.typeDeclarationMember(typeDeclaration.children, headingLevel)));
            }
        }
    }
    if (!parentHeadingLevel) {
        md.push(context.partials.inheritance(declaration, headingLevel));
    }
    return md.join('\n\n');
}
