"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.member = void 0;
const typedoc_1 = require("typedoc");
const els_1 = require("../support/els");
const helpers_1 = require("../support/helpers");
function member(context, reflection) {
    const md = [];
    const headingLevel = (0, helpers_1.getReflectionHeadingLevel)(reflection, context.getOption('groupByKinds'));
    if (context.getOption('namedAnchors')) {
        md.push(`<a id="${reflection.anchor}" name="${reflection.anchor}"></a>`);
    }
    if (!reflection.hasOwnDocument) {
        md.push((0, els_1.heading)(headingLevel, `${(0, helpers_1.getReflectionTitle)(reflection)}`));
    }
    if ([
        typedoc_1.ReflectionKind.Class,
        typedoc_1.ReflectionKind.Interface,
        typedoc_1.ReflectionKind.Enum,
    ].includes(reflection.kind)) {
        md.push(context.partials.reflectionMember(reflection));
    }
    else {
        if (reflection.signatures) {
            reflection.signatures.forEach((signature) => {
                md.push(context.partials.signatureMember(signature));
            });
        }
        else {
            if (reflection instanceof typedoc_1.ReferenceReflection) {
                md.push(context.partials.referenceMember(reflection));
            }
            if (reflection instanceof typedoc_1.DeclarationReflection) {
                md.push(context.partials.declarationMember(reflection));
            }
        }
    }
    return md.join('\n\n');
}
exports.member = member;
