"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.signatureMemberIdentifier = void 0;
const els_1 = require("../support/els");
const utils_1 = require("../support/utils");
function signatureMemberIdentifier(context, signature) {
    var _a, _b;
    const md = [];
    if (signature.parent && ((_a = signature.parent.flags) === null || _a === void 0 ? void 0 : _a.length) > 0) {
        md.push(signature.parent.flags.map((flag) => `\`${flag}\``).join(' ') + ' ');
    }
    if (!['__call', '__type'].includes(signature.name)) {
        md.push((0, els_1.bold)((0, utils_1.escapeChars)(signature.name)));
    }
    if (signature.typeParameters) {
        md.push(`\\<${signature.typeParameters
            .map((typeParameter) => typeParameter.name)
            .join(', ')}\\>`);
    }
    const getParameters = (parameters = []) => {
        const firstOptionalParamIndex = parameters.findIndex((parameter) => parameter.flags.isOptional);
        return parameters
            .map((param, i) => {
            const paramsmd = [parameters.length > 2 ? '\n  ' : ''];
            if (param.flags.isRest) {
                paramsmd.push('...');
            }
            const paramItem = `${(0, utils_1.escapeChars)(param.name)}${param.flags.isOptional ||
                (firstOptionalParamIndex !== -1 && i > firstOptionalParamIndex)
                ? '?'
                : ''}: ${context.partials.someType(param.type, 'all')}`;
            paramsmd.push(paramItem);
            if (param.defaultValue) {
                paramsmd.push(` = ${(0, els_1.backTicks)(param.defaultValue)}`);
            }
            return paramsmd.join('');
        })
            .join(`, `);
    };
    md.push(signature.parameters && ((_b = signature.parameters) === null || _b === void 0 ? void 0 : _b.length) > 0
        ? `(${getParameters(signature.parameters)})`
        : '()');
    if (signature.type) {
        md.push(`: ${context.partials.someType(signature.type, 'all')}`);
    }
    return md.join('');
}
exports.signatureMemberIdentifier = signatureMemberIdentifier;
