"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.signatureMember = void 0;
const els_1 = require("../support/els");
const helpers_1 = require("../support/helpers");
function signatureMember(context, signature, parentHeadingLevel) {
    const md = [];
    if (parentHeadingLevel) {
        md.push((0, els_1.blockQuoteBlock)(signatureBody(context, signature, parentHeadingLevel)));
    }
    else {
        md.push(signatureBody(context, signature));
    }
    return md.join('\n\n');
}
exports.signatureMember = signatureMember;
function signatureBody(context, signature, parentHeadingLevel) {
    var _a, _b, _c, _d;
    const md = [];
    const headingLevel = (parentHeadingLevel
        ? parentHeadingLevel
        : (0, helpers_1.getReflectionHeadingLevel)(signature.parent, context.getOption('groupByKinds'))) + 1;
    if (context.getOption('indentifiersAsCodeBlocks')) {
        md.push((0, els_1.codeBlock)(context.partials.signatureMemberIdentifier(signature)));
    }
    else {
        md.push(`> ${context.partials.signatureMemberIdentifier(signature)}`);
    }
    if (signature.comment) {
        md.push(context.partials.comment(signature.comment, headingLevel));
    }
    if (!parentHeadingLevel && signature.sources) {
        md.push(context.partials.sources(signature));
    }
    const typeDeclaration = (_a = signature.type) === null || _a === void 0 ? void 0 : _a.declaration;
    if ((_b = signature.typeParameters) === null || _b === void 0 ? void 0 : _b.length) {
        md.push((0, els_1.heading)(headingLevel, 'Type parameters'));
        md.push(context.partials.typeParametersTable(signature.typeParameters));
    }
    if ((_c = signature.parameters) === null || _c === void 0 ? void 0 : _c.length) {
        md.push((0, els_1.heading)(headingLevel, 'Parameters'));
        md.push(context.partials.parametersTable(signature.parameters));
    }
    if (signature.type) {
        md.push((0, els_1.heading)(headingLevel, 'Returns'));
        md.push(context.partials.someType(signature.type, 'all'));
        if ((_d = signature.comment) === null || _d === void 0 ? void 0 : _d.blockTags.length) {
            const tags = signature.comment.blockTags
                .filter((tag) => tag.tag === '@returns')
                .map((tag) => context.partials.commentParts(tag.content));
            md.push(tags.join('\n\n'));
        }
        if (typeDeclaration === null || typeDeclaration === void 0 ? void 0 : typeDeclaration.signatures) {
            typeDeclaration.signatures.forEach((signature) => {
                md.push(context.partials.signatureMember(signature, headingLevel));
            });
        }
        if (typeDeclaration === null || typeDeclaration === void 0 ? void 0 : typeDeclaration.children) {
            if (context.getOption('typeDeclarationFormat').toLowerCase() === 'table') {
                md.push(context.partials.propertiesTable(typeDeclaration.children));
            }
            else {
                md.push(context.partials.typeDeclarationMember(typeDeclaration.children, headingLevel));
            }
        }
        if (!parentHeadingLevel) {
            md.push(context.partials.inheritance(signature, headingLevel));
        }
    }
    return md.join('\n\n');
}
