"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.members = void 0;
const typedoc_1 = require("typedoc");
const constants_1 = require("../support/constants");
const els_1 = require("../support/els");
const helpers_1 = require("../support/helpers");
function members(context, container) {
    var _a;
    const md = [];
    if (container.categories && container.categories.length) {
        container.categories
            .filter((category) => !category.allChildrenHaveOwnDocument())
            .forEach((item) => item.children
            .filter((item) => !item.hasOwnDocument)
            .forEach((item) => {
            md.push(context.partials.member(item));
        }));
    }
    else {
        (_a = container.groups) === null || _a === void 0 ? void 0 : _a.filter((group) => !group.allChildrenHaveOwnDocument()).forEach((group) => {
            const headingLevel = (0, helpers_1.getGroupHeadingLevel)(container, context.getOption('groupByKinds'));
            if (group.categories) {
                if (context.getOption('groupByKinds') ||
                    constants_1.SYMBOLS_WITH_DOCUMENTS.includes(container.kind)) {
                    md.push((0, els_1.heading)(headingLevel, group.title));
                }
                group.categories.forEach((groupItem) => groupItem.children.forEach((item) => {
                    md.push(context.partials.member(item));
                }));
            }
            else {
                if (context.getOption('groupByKinds') ||
                    constants_1.SYMBOLS_WITH_DOCUMENTS.includes(container.kind)) {
                    md.push((0, els_1.heading)(headingLevel, group.title));
                }
                const isPropertiesGroup = group.children.every((child) => child.kindOf(typedoc_1.ReflectionKind.Property));
                const isEnumGroup = group.children.every((child) => child.kindOf(typedoc_1.ReflectionKind.EnumMember));
                if (isPropertiesGroup &&
                    context.getOption('propertiesFormat').toLowerCase() === 'table') {
                    md.push(context.partials.propertiesTable(group.children));
                }
                else if (isEnumGroup &&
                    context.getOption('enumMembersFormat').toLowerCase() === 'table') {
                    md.push(context.partials.enumMembersTable(group.children));
                }
                else {
                    group.children
                        .filter((item) => !item.hasOwnDocument)
                        .forEach((groupChild) => {
                        md.push(context.partials.member(groupChild));
                        if (constants_1.SYMBOLS_WITH_DOCUMENTS.includes(groupChild.kind)) {
                            md.push((0, els_1.horizontalRule)());
                        }
                    });
                }
            }
        });
    }
    return md.join('\n\n');
}
exports.members = members;
