"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.propertiesTable = void 0;
const typedoc_1 = require("typedoc");
const els_1 = require("../support/els");
const helpers_1 = require("../support/helpers");
function propertiesTable(context, props) {
    const comments = props.map((param) => { var _a; return !!((_a = param.comment) === null || _a === void 0 ? void 0 : _a.hasVisibleComponent()); });
    const hasComments = comments.some((value) => Boolean(value));
    const hasModifiers = props.some((prop) => prop.flags.length);
    const headers = ['Property'];
    if (hasModifiers) {
        headers.push('Modifiers');
    }
    headers.push('Type');
    if (hasComments) {
        headers.push('Description');
    }
    const flattenParams = (current) => {
        var _a, _b, _c;
        return (_c = (_b = (_a = current.type) === null || _a === void 0 ? void 0 : _a.declaration) === null || _b === void 0 ? void 0 : _b.children) === null || _c === void 0 ? void 0 : _c.reduce((acc, child) => {
            const childObj = {
                ...child,
                name: `${current.name}.${child.name}`,
            };
            return parseParams(childObj, acc);
        }, []);
    };
    const parseParams = (current, acc) => {
        var _a, _b;
        const shouldFlatten = (_b = (_a = current.type) === null || _a === void 0 ? void 0 : _a.declaration) === null || _b === void 0 ? void 0 : _b.children;
        return shouldFlatten
            ? [...acc, current, ...flattenParams(current)]
            : [...acc, current];
    };
    const properties = props.reduce((acc, current) => parseParams(current, acc), []);
    const rows = [];
    properties.forEach((property) => {
        const propertyType = (0, helpers_1.getDeclarationType)(property);
        const row = [];
        row.push(context.partials.declarationMemberName(property, false));
        if (hasModifiers) {
            if (property.flags.length) {
                row.push(property.flags.map((flag) => (0, els_1.backTicks)(flag.toLowerCase())).join(' '));
            }
            else {
                row.push('-');
            }
        }
        if (propertyType) {
            row.push(context.partials.someType(propertyType, 'object'));
        }
        if (hasComments) {
            const comments = getComments(property);
            if (comments) {
                row.push((0, helpers_1.tableComments)(context.partials.comment(comments)));
            }
            else {
                row.push('-');
            }
        }
        rows.push(row);
    });
    return (0, els_1.table)(headers, rows);
}
exports.propertiesTable = propertiesTable;
function getComments(property) {
    var _a, _b, _c;
    if (property.type instanceof typedoc_1.ReflectionType) {
        if ((_b = (_a = property.type) === null || _a === void 0 ? void 0 : _a.declaration) === null || _b === void 0 ? void 0 : _b.signatures) {
            return (_c = property.type) === null || _c === void 0 ? void 0 : _c.declaration.signatures[0].comment;
        }
    }
    if (property.signatures) {
        return property.signatures[0].comment;
    }
    return property.comment;
}
