"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.typeParametersTable = void 0;
const els_1 = require("../support/els");
const helpers_1 = require("../support/helpers");
function typeParametersTable(context, typeParameters) {
    const hasDefault = typeParameters.some((typeParameter) => Boolean(typeParameter.default));
    const hasComments = typeParameters.some((typeParameter) => Boolean(typeParameter.comment));
    const headers = ['Parameter'];
    if (hasDefault) {
        headers.push('Default');
    }
    if (hasComments) {
        headers.push('Description');
    }
    const rows = [];
    typeParameters === null || typeParameters === void 0 ? void 0 : typeParameters.forEach((typeParameter) => {
        const row = [];
        const nameCol = [];
        nameCol.push(typeParameter.name);
        if (typeParameter.type) {
            nameCol.push(`${(0, els_1.italic)('extends')} ${context.partials.someType(typeParameter.type)}`);
        }
        row.push(nameCol.join(' '));
        if (hasDefault) {
            if (typeParameter.default) {
                row.push(context.partials.someType(typeParameter.default));
            }
            else {
                row.push('-');
            }
        }
        if (hasComments) {
            if (typeParameter.comment) {
                row.push((0, helpers_1.tableComments)(context.partials.comment(typeParameter.comment)));
            }
            else {
                row.push('-');
            }
        }
        rows.push(row);
    });
    return (0, els_1.table)(headers, rows);
}
exports.typeParametersTable = typeParametersTable;
