"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.renderMarkdown = exports.generateMarkdown = exports.MarkdownRendererEvent = void 0;
const fs = __importStar(require("fs"));
const path = __importStar(require("path"));
const typedoc_1 = require("typedoc");
class MarkdownRendererEvent extends typedoc_1.RendererEvent {
}
exports.MarkdownRendererEvent = MarkdownRendererEvent;
async function generateMarkdown(project, out) {
    const start = Date.now();
    out = path.resolve(out);
    await this.renderer.render(project, out);
    if (this.logger.hasErrors()) {
        this.logger.error('Documentation could not be generated due to the errors above.');
    }
    else {
        this.logger.info(`Documentation generated at ${out}`);
        this.logger.verbose(`Markdown rendering took ${Date.now() - start}ms`);
    }
}
exports.generateMarkdown = generateMarkdown;
async function renderMarkdown(project, outputDirectory) {
    var _a, _b;
    this.renderStartTime = Date.now();
    if (this.cleanOutputDir) {
        try {
            fs.rmSync(outputDirectory, { recursive: true, force: true });
        }
        catch (error) {
            this.application.logger.warn('Could not empty the output directory.');
            return;
        }
    }
    try {
        fs.mkdirSync(outputDirectory, { recursive: true });
    }
    catch (error) {
        this.application.l.error(`Could not create output directory ${outputDirectory}.`);
        return;
    }
    if (this.githubPages) {
        try {
            const text = 'TypeDoc added this file to prevent GitHub Pages from ' +
                'using Jekyll. You can turn off this behavior by setting ' +
                'the `githubPages` option to false.';
            fs.writeFileSync(path.join(outputDirectory, '.nojekyll'), text);
        }
        catch (error) {
            this.application.warn('Could not create .nojekyll file.');
            return;
        }
    }
    this.prepareTheme();
    const output = new MarkdownRendererEvent(typedoc_1.RendererEvent.BEGIN, outputDirectory, project);
    output.urls = this.theme.getUrls(project);
    output.navigation = this.theme.getNavigation(project);
    this.trigger(output);
    await Promise.all(this.preRenderAsyncJobs.map((job) => job(output)));
    this.preRenderAsyncJobs = [];
    this.application.logger.verbose(`There are ${(_a = output.urls) === null || _a === void 0 ? void 0 : _a.length} pages to write.`);
    (_b = output.urls) === null || _b === void 0 ? void 0 : _b.filter((urlMapping) => urlMapping.model instanceof typedoc_1.ProjectReflection ||
        urlMapping.model instanceof typedoc_1.DeclarationReflection).forEach((urlMapping) => {
        this.renderDocument(...output.createPageEvent(urlMapping));
    });
    await Promise.all(this.postRenderAsyncJobs.map((job) => job(output)));
    this.postRenderAsyncJobs = [];
    this.trigger(typedoc_1.RendererEvent.END, output);
    this.theme = void 0;
}
exports.renderMarkdown = renderMarkdown;
