import { ArrayType, ConditionalType, ContainerReflection, Comment, CommentDisplayPart, DeclarationHierarchy, DeclarationReflection, InferredType, IntersectionType, IntrinsicType, IndexedAccessType, LiteralType, PageEvent, ParameterReflection, ProjectReflection, QueryType, ReferenceReflection, ReferenceType, ReflectionType, SignatureReflection, SomeType, TupleType, TypeOperatorType, TypeParameterReflection, UnionType, UnknownType } from 'typedoc';
import { MarkdownThemeRenderContext } from './theme-render-context';
import { Collapse } from './models';
export type Templates = {
    memberTemplate: (page: PageEvent<DeclarationReflection>) => string;
    projectTemplate: (page: PageEvent<ProjectReflection>) => string;
    readmeTemplate: (page: PageEvent<ProjectReflection>) => string;
    reflectionTemplate: (page: PageEvent<DeclarationReflection>) => string;
};
export type Partials = {
    breadcrumbs: (page: PageEvent<DeclarationReflection | ProjectReflection>) => string;
    commentParts: (parts: CommentDisplayPart[]) => string;
    comment: (comment: Comment, headingLevel?: number | undefined) => string;
    frontmatter: (page: PageEvent<DeclarationReflection | ProjectReflection>) => string;
    hierarchy: (declarationHierarchy: DeclarationHierarchy) => string;
    declarationMemberIdentifier: (reflection: DeclarationReflection) => string;
    declarationMemberName: (declaration: DeclarationReflection, emphasis?: boolean) => string;
    declarationMember: (declaration: DeclarationReflection, parentHeadingLevel?: number | undefined) => string;
    indexSignatureTitle: (signature: SignatureReflection) => string;
    inheritance: (reflection: DeclarationReflection | SignatureReflection, headingLevel: number) => string;
    referenceMember: (props: ReferenceReflection) => string;
    reflectionMember: (reflection: DeclarationReflection) => string;
    signatureMemberIdentifier: (signature: SignatureReflection) => string;
    signatureMember: (signature: SignatureReflection, parentHeadingLevel?: number | undefined) => string;
    sources: (reflection: DeclarationReflection | SignatureReflection) => string;
    member: (reflection: DeclarationReflection) => string;
    typeDeclarationMember: (declarations: DeclarationReflection[], parentHeadingLevel: number) => string;
    members: (container: ContainerReflection) => string;
    navigation: (project: ProjectReflection) => string;
    pageTitle: (page: PageEvent<DeclarationReflection | ProjectReflection>) => string;
    enumMembersTable: (props: DeclarationReflection[]) => string;
    parametersTable: (parameters: ParameterReflection[]) => string;
    propertiesTable: (props: DeclarationReflection[]) => string;
    typeParametersTable: (typeParameters: TypeParameterReflection[]) => string;
    toc: (reflection: DeclarationReflection | ProjectReflection) => string;
    arrayType: (arrayType: ArrayType) => string;
    conditionalType: (conditionalType: ConditionalType) => string;
    declarationType: (declarationReflection: DeclarationReflection, collapse?: Collapse) => string;
    functionType: (modelSignatures: SignatureReflection[]) => string;
    indexAccessType: (model: IndexedAccessType) => string;
    inferredType: (model: InferredType) => string;
    intersectionType: (model: IntersectionType) => string;
    intrinsicType: (model: IntrinsicType) => string;
    literalType: (literalType: LiteralType) => string;
    queryType: (queryType: QueryType) => string;
    referenceType: (referenceType: ReferenceType) => string;
    reflectionType: (reflectionType: ReflectionType, collapse: Collapse) => string;
    someType: (someType: SomeType, collapse?: Collapse) => string;
    tupleType: (tupleType: TupleType) => string;
    typeOperatorType: (model: TypeOperatorType) => string;
    unionType: (unionType: UnionType) => string;
    unknownType: (model: UnknownType) => string;
};
export declare const templates: (context: MarkdownThemeRenderContext) => Templates;
export declare const partials: (context: MarkdownThemeRenderContext) => Partials;
