"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getProjectDisplayName = exports.getDeclarationType = exports.getTagName = exports.tableComments = exports.getFlags = exports.getTypeParameters = exports.getReflectionTitle = exports.getReflectionHeadingLevel = exports.getGroupHeadingLevel = exports.getIndexHeadingLevel = void 0;
const typedoc_1 = require("typedoc");
const els_1 = require("./els");
const utils_1 = require("./utils");
function getIndexHeadingLevel(reflection, groupByKinds) {
    if (reflection.kindOf([
        typedoc_1.ReflectionKind.Project,
        typedoc_1.ReflectionKind.Module,
        typedoc_1.ReflectionKind.Namespace,
    ]) ||
        reflection.hasOwnDocument) {
        return 2;
    }
    return groupByKinds ? 4 : 3;
}
exports.getIndexHeadingLevel = getIndexHeadingLevel;
function getGroupHeadingLevel(container, groupByKinds) {
    if (container.kindOf(typedoc_1.ReflectionKind.Project)) {
        return 2;
    }
    return container.hasOwnDocument ? 2 : groupByKinds ? 4 : 3;
}
exports.getGroupHeadingLevel = getGroupHeadingLevel;
function getReflectionHeadingLevel(reflection, groupByKinds) {
    var _a, _b, _c, _d;
    if (reflection.hasOwnDocument) {
        return 1;
    }
    if ((_a = reflection === null || reflection === void 0 ? void 0 : reflection.parent) === null || _a === void 0 ? void 0 : _a.kindOf(typedoc_1.ReflectionKind.Project)) {
        return groupByKinds ? 3 : 2;
    }
    if (reflection.kindOf(typedoc_1.ReflectionKind.Constructor)) {
        return ((_b = reflection.parent) === null || _b === void 0 ? void 0 : _b.hasOwnDocument) ? 3 : 5;
    }
    if (groupByKinds) {
        return ((_c = reflection.parent) === null || _c === void 0 ? void 0 : _c.hasOwnDocument) ? 3 : 5;
    }
    return ((_d = reflection.parent) === null || _d === void 0 ? void 0 : _d.hasOwnDocument) ? 2 : 4;
}
exports.getReflectionHeadingLevel = getReflectionHeadingLevel;
function getReflectionTitle(reflection, typeParams = false) {
    var _a;
    const md = [(0, utils_1.escapeChars)(reflection.name)];
    if ((_a = reflection.signatures) === null || _a === void 0 ? void 0 : _a.length) {
        md.push('()');
    }
    if (typeParams) {
        md.push(getTypeParameters(reflection));
    }
    return md.join('');
}
exports.getReflectionTitle = getReflectionTitle;
function getTypeParameters(reflection) {
    if (reflection.typeParameters) {
        const typeParameters = reflection.typeParameters
            .map((typeParameter) => typeParameter.name)
            .join(', ');
        return `\\<${typeParameters}\\>`;
    }
    return '';
}
exports.getTypeParameters = getTypeParameters;
function getFlags(reflection) {
    var _a;
    if (((_a = reflection.flags) === null || _a === void 0 ? void 0 : _a.length) > 0 && !reflection.flags.isRest) {
        return reflection.flags.map((flag) => (0, els_1.backTicks)(flag)).join(' ');
    }
    return null;
}
exports.getFlags = getFlags;
function tableComments(str) {
    return (0, utils_1.stripLineBreaks)(str).replace(/\|/g, '\\|');
}
exports.tableComments = tableComments;
function getTagName(tag) {
    return tag.tag.substring(1);
}
exports.getTagName = getTagName;
function getDeclarationType(declaration) {
    if (declaration.getSignature) {
        return declaration.getSignature.type;
    }
    if (declaration.setSignature) {
        return declaration.setSignature.type;
    }
    return declaration.type;
}
exports.getDeclarationType = getDeclarationType;
function getProjectDisplayName(project, includeVersion) {
    const version = includeVersion ? ` - v${project.packageVersion}` : '';
    return `${project.name}${version}`;
}
exports.getProjectDisplayName = getProjectDisplayName;
