"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.slugify = exports.camelToTitleCase = exports.stripLineBreaks = exports.stripComments = exports.unEscapeChars = exports.escapeTableCol = exports.escapeChars = void 0;
function escapeChars(str) {
    return str
        .replace(/>/g, '\\>')
        .replace(/</g, '\\<')
        .replace(/{/g, '\\{')
        .replace(/_/g, '\\_')
        .replace(/`/g, '\\`')
        .replace(/\|/g, '\\|');
}
exports.escapeChars = escapeChars;
function escapeTableCol(str) {
    return str.replace(/(?<!\\)\|/g, '\\|');
}
exports.escapeTableCol = escapeTableCol;
function unEscapeChars(str) {
    return str
        .replace(/\\</g, '<')
        .replace(/\\>/g, '>')
        .replace(/\\_/g, '_')
        .replace(/\\{/g, '{')
        .replace(/`/g, '')
        .replace(/\*/g, '')
        .replace(/\\\|/g, '|')
        .replace(/\[([^\[\]]*)\]\((.*?)\)/gm, '$1');
}
exports.unEscapeChars = unEscapeChars;
function stripComments(str) {
    return str
        .replace(/(?:\/\*(?:[\s\S]*?)\*\/)|(?:^\s*\/\/(?:.*)$)/g, ' ')
        .replace(/\n/g, '')
        .replace(/^\s+|\s+$|(\s)+/g, '$1');
}
exports.stripComments = stripComments;
function stripLineBreaks(str, includeHTML = true) {
    return str
        ? str
            .replace(/\n/g, includeHTML ? '<br />' : ' ')
            .replace(/\r/g, '')
            .replace(/\t/g, ' ')
            .trim()
        : '';
}
exports.stripLineBreaks = stripLineBreaks;
function camelToTitleCase(text) {
    return (text.substring(0, 1).toUpperCase() +
        text.substring(1).replace(/[a-z][A-Z]/g, (x) => `${x[0]} ${x[1]}`));
}
exports.camelToTitleCase = camelToTitleCase;
function slugify(str) {
    return str
        .toLowerCase()
        .trim()
        .replace(/[^\w\s-]/g, '')
        .replace(/[\s_-]+/g, '-')
        .replace(/^-+|-+$/g, '');
}
exports.slugify = slugify;
